@@ -17,12 +17,16 @@ class init_anim:
 
 
     Arguments:
+    ----------
         :param t: :class:`~np.ndarray', contains the time information that corresponds with the six degrees of freedom data 
         :param speed_up: float, the "real time speed up" or the ratio of the duration of the data to the duration of the animation 
         :param scale: float, global physical scale factor of the animation, i.e., .1 will reduce everything to be 1/10th its original size
-
     """
     def __init__(self, t, speed_up, scale):
+        """
+        Attributes:
+        -----------
+        """
 
         self.frame_rate = bpy.context.scene.render.fps
         """float: frame rate of animation"""
@@ -56,9 +60,16 @@ class ref_frame:
         :param name: str, the Blender object name of the reference frame
         :param parent: :class:`~bpy.data.object', the Blender object parent of this reference frame 
         :param anim: :class:`~bpsci.core.init_anim`), class object that was used to initialize the animation
-
+    
+    Attributes:
+    -----------
     """
     def __init__(self, name, parent, anim):
+
+        """
+        Attributes:
+        -----------
+        """
         
         self.name = name
         """str: the Blender object name of the reference frame"""
@@ -94,6 +105,7 @@ class ref_frame:
 
 
         Arguments:
+        ----------
             :param quat: :class:`~np.ndarray', an numpy array of one quaternion
             :param x: float, the x position 
             :param y: float, the y position 
@@ -122,6 +134,7 @@ class ref_frame:
 
 
         Arguments:
+        ----------
             :param quat: :class:`~np.ndarray', an numpy array of quaternions over time
             :param x: :class:`~np.ndarray', the x position over time
             :param y: :class:`~np.ndarray', the y position over time
@@ -160,6 +173,7 @@ class dyn_obj:
     The main building block of all dynamic visualizations 
 
     Arguments:
+    ----------
         :param obj: :class:`~bpy.data.object', the Blender object that will be animated
         :param pa: :class:`~np.ndarray', the offset of the principal axes specified by the :param euler_type:
         :param euler_type: str. the Euler angle order (i.e. 'xyz' for 1,2,3 or 'zxz' for 3,1,3)
@@ -168,6 +182,10 @@ class dyn_obj:
 
     """
     def __init__(self, obj, pa, euler_type, parent, anim):
+        """
+        Attributes:
+        -----------
+        """
 
         self.parent = parent
         """:class:`~bpy.data.object': the Blender object parent of this reference frame"""
@@ -225,10 +243,14 @@ class dyn_obj:
         Creates a static or dynamic positional streamline for a :class:`~bpsci.core.dyn_obj`
 
         Arguments:
+        ----------
             :param staticity (str): a string (either 'static' or 'dynamic') that specifies whether the the streamline is animated over time
             :param int_x: :class:`~np.ndarray', a numpy array of the x position over time
             :param int_y: :class:`~np.ndarray', a numpy array of the y position over time
             :param int_z: :class:`~np.ndarray', a numpy array of the z position over time
+        
+        Attributes:
+        -----------
         """
 
 
@@ -279,15 +301,22 @@ class dyn_vec:
     Initializes a dynamic vector`
 
     Arguments:
+    ----------
         :param parent: :class:`~bpy.data.object', the Blender object the vector is associated with
         :param name: str, the Blender object name of the vector ('_vector' will be appended to this name)
         :param scale_mag: float, the scaling factor of the vector's magnitude axis (purely aesthetic)
         :param scale_off: float, the scaling factor of the vector's off-axes (purely aesthetic)
         :param offset: tuple[float], offset of vector from the parent object (purely aesthetic)
         :param anim: :class:`~bpsci.core.init_anim`, class object that was used to initialize the animation
+
     """
     def __init__(self, parent, name, scale_mag, scale_off, offset, anim):
 
+        """
+        Attributes:
+        -----------
+        """
+
         self.parent = parent
         """:class:`~bpy.data.object': the Blender object parent of this reference frame"""
 
@@ -322,9 +351,13 @@ class dyn_vec:
         Animates a dynamic vector
 
         Arguments:
-        :param x: :class:`~np.ndarray', a numpy array of the x component over time
-        :param y: :class:`~np.ndarray',  a numpy array of the y component over time
-        :param z: :class:`~np.ndarray', a numpy array of the z component over time
+        ----------
+            :param x: :class:`~np.ndarray', a numpy array of the x component over time
+            :param y: :class:`~np.ndarray',  a numpy array of the y component over time
+            :param z: :class:`~np.ndarray', a numpy array of the z component over time
+
+        Attributes:
+        -----------
         """
 
         frames = self.frames
@@ -371,6 +404,7 @@ class anim_text:
     Creates animated text
 
     Arguments:
+    ----------
         :param name: str, the Blender object name of the text ('_text' will be appended to this name)
         :param parent: :class:`~bpy.data.object', the Blender object parent of this text 
         :param anim: :class:`~bpsci.core.init_anim`, class object that was used to initialize the animation
@@ -378,9 +412,14 @@ class anim_text:
         :param label: str, a label to append to the text (if no label is desired, pass '')
         :param fix_place: int, the number of decimal places to fix the text to
         :param if_str: bool, whether or not the data is a numerical or string vector. Currently only numerical vectors are supported.
+
     """
     def __init__(self, name, parent, anim, data, label, fix_place, if_str):
-        
+
+        """
+        Attributes:
+        -----------
+        """
 
         self.anim = anim
 
